==> flink-1.15.0-src.tgz: flink-1.15.0/flink-core/src/test/java/org/apache/flink/api/java/typeutils/EitherTypeInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.api.java.typeutils;

import org.apache.flink.api.common.typeinfo.BasicTypeInfo;
import org.apache.flink.api.common.typeutils.TypeInformationTestBase;
import org.apache.flink.api.java.tuple.Tuple2;

/** Test for {@link EitherTypeInfo}. */
public class EitherTypeInfoTest extends TypeInformationTestBase<EitherTypeInfo<?, ?>> {

    @Override
    protected EitherTypeInfo<?, ?>[] getTestData() {
        return new EitherTypeInfo<?, ?>[] {
            new EitherTypeInfo<>(BasicTypeInfo.INT_TYPE_INFO, BasicTypeInfo.STRING_TYPE_INFO),
            new EitherTypeInfo<>(
                    BasicTypeInfo.INT_TYPE_INFO,
                    new TupleTypeInfo<Tuple2<Double, Long>>(
                            TypeExtractor.getForClass(Double.class),
                            TypeExtractor.getForClass(String.class)))
        };
    }
}

==> flink-1.20.2-src.tgz: flink-1.20.2/flink-core/src/test/java/org/apache/flink/api/java/typeutils/EitherTypeInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.api.java.typeutils;

import org.apache.flink.api.common.typeinfo.BasicTypeInfo;
import org.apache.flink.api.common.typeutils.TypeInformationTestBase;
import org.apache.flink.api.java.tuple.Tuple2;

/** Test for {@link EitherTypeInfo}. */
class EitherTypeInfoTest extends TypeInformationTestBase<EitherTypeInfo<?, ?>> {

    @Override
    protected EitherTypeInfo<?, ?>[] getTestData() {
        return new EitherTypeInfo<?, ?>[] {
            new EitherTypeInfo<>(BasicTypeInfo.INT_TYPE_INFO, BasicTypeInfo.STRING_TYPE_INFO),
            new EitherTypeInfo<>(
                    BasicTypeInfo.INT_TYPE_INFO,
                    new TupleTypeInfo<Tuple2<Double, Long>>(
                            TypeExtractor.getForClass(Double.class),
                            TypeExtractor.getForClass(String.class)))
        };
    }
}
